# dr-eureka

[![Release](https://img.shields.io/gitlab/v/release/mshepherd%2Fdr-eureka)](https://img.shields.io/gitlab/v/release/mshepherd%2Fdr-eureka)
[![Build status](https://gitlab.com/mshepherd/dr-eureka/badges/main/pipeline.svg)](https://gitlab.com/mshepherd/dr-eureka/-/pipelines/latest)
[![coverage](https://gitlab.com/mshepherd/dr-eureka/badges/main/coverage.svg)](https://coverage_report_placeholde.html)
[![License](https://img.shields.io/gitlab/license/mshepherd/dr-eureka)](https://img.shields.io/gitlab/license/mshepherd/dr-eureka)

Dr Eureka implementation and solver
